@@ -51,24 +51,6 @@ read_xfrm <- function(nodeset, file, name){
           name = name )
 }
 
-fortify_pml_images <- function(x, str){
-
-  slide <- x$slide$get_slide(x$cursor)
-  ref <- slide$rel_df()
-
-  ref <- ref[ref$ext_src != "",]
-  doc <- as_xml_document(str)
-  for(id in seq_along(ref$ext_src) ){
-    xpth <- paste0("//p:pic/p:blipFill/a:blip",
-                   sprintf( "[contains(@r:embed,'%s')]", ref$ext_src[id]),
-                   "")
-
-    src_nodes <- xml_find_all(doc, xpth)
-    xml_attr(src_nodes, "r:embed") <- ref$id[id]
-  }
-  as.character(doc)
-}
-
 fortify_master_xfrm <- function(master_xfrm){
 
   master_xfrm <- as.data.frame(master_xfrm)
@@ -263,13 +245,28 @@ is_office_doc_edited <- function(file) {
   file.exists(file.path(dirname(file), edit_name))
 }
 
-# this is copied from package htmltools
-#' @importFrom utils URLencode
-urlEncodePath <- function (x){
-  vURLEncode <- Vectorize(URLencode, USE.NAMES = FALSE)
-  gsub("%2[Ff]", "/", vURLEncode(x, TRUE))
+.url_special_chars <- list(
+  `&` = '&amp;',
+  `<` = '&lt;',
+  `>` = '&gt;',
+  `'` = '&#39;',
+  `"` = '&quot;',
+  ` ` = "&nbsp;"
+)
+officer_url_encode <- function(x) {
+  for (chr in names(.url_special_chars)) {
+    x <- gsub(chr, .url_special_chars[[chr]], x, fixed = TRUE, useBytes = TRUE)
+  }
+  Encoding(x) <- "UTF-8"
+  x
+}
+officer_url_decode <- function(x) {
+  for (chr in rev(names(.url_special_chars))) {
+    x <- gsub(.url_special_chars[[chr]], chr, x, fixed = TRUE, useBytes = TRUE)
+  }
+  Encoding(x) <- "UTF-8"
+  x
 }
-
 # htmlEscapeCopy ----
 htmlEscapeCopy <- local({
 
